# Generated by roxygen2: do not edit by hand

S3method(multi_predict,"_fishnet")
S3method(predict,"_fishnet")
S3method(predict_numeric,"_fishnet")
S3method(predict_raw,"_fishnet")
S3method(tidy,hurdle)
S3method(tidy,zeroinfl)
export(tidy)
import(parsnip)
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,full_join)
importFrom(generics,tidy)
importFrom(purrr,map)
importFrom(purrr,map_lgl)
importFrom(rlang,enquo)
importFrom(rlang,enquos)
importFrom(rlang,expr)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(tibble,as_tibble)
importFrom(tibble,is_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,gather)
importFrom(utils,globalVariables)
